# qual-gis


[![image](https://img.shields.io/pypi/v/qual-gis.svg)](https://pypi.python.org/pypi/qual-gis)
[![image](https://img.shields.io/conda/vn/conda-forge/qual-gis.svg)](https://anaconda.org/conda-forge/qual-gis)


**Qualitative GIS tools**


-   Free software: MIT License
-   Documentation: https://fschrupprivero.github.io/qual-gis
    

## Features

-   TODO
